@@ -17,8 +17,33 @@ $Id: __init__.py 70825 2006-10-20 01:34:05Z rogerineichen $
 __docformat__ = 'restructuredtext'
 
 import unittest
+
 from zope.testing import doctest
-from zope.app.testing import placelesssetup, setup
+from zope.app.testing import setup
+from zope.interface.verify import verifyObject
+from zope.publisher.browser import TestRequest
+
+
+def doctest_Breadcrumbs_interface():
+    """Test that Breadcrumbs matches the interface
+
+        >>> from z3c.breadcrumb import browser, interfaces
+        >>> breadcrumbs = browser.Breadcrumbs(None, None)
+        >>> verifyObject(interfaces.IBreadcrumbs, breadcrumbs)
+        True
+
+    """
+
+
+def doctest_GenericBreadcrumb_interface():
+    """Test that GenericBreadcrumb matches the interface
+
+        >>> from z3c.breadcrumb import browser, interfaces
+        >>> breadcrumb = browser.GenericBreadcrumb(rootFolder, TestRequest())
+        >>> verifyObject(interfaces.IBreadcrumb, breadcrumb)
+        True
+
+    """
 
 
 def setUp(test):
@@ -30,9 +55,11 @@ def tearDown(test):
 
 
 def test_suite():
-    return unittest.TestSuite((
+    return unittest.TestSuite([
             doctest.DocFileSuite(
                 'README.txt',
                 setUp=setUp, tearDown=tearDown,
                 optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS),
-            ))
+            doctest.DocTestSuite(
+                setUp=setUp, tearDown=tearDown),
+            ])
